async fn get_course_material_document(
endpoint: &mut Url,
api_key: &SecretString,
) -> Result<CourseMaterialDocument>Expand description
Get a document from the search index with a LLM-provided get url
async fn get_course_material_document(
endpoint: &mut Url,
api_key: &SecretString,
) -> Result<CourseMaterialDocument>Get a document from the search index with a LLM-provided get url