pub fn parse_document_filepath(
filepath: &str,
) -> ChatbotResult<DocumentProperties>Expand description
Parse the filepath of a document from the Azure search index and return the page_id of the document. The page id is the same as the id of the page in our DB.